<?php
// $Id: node_style.admin.inc,v 1.1.2.4 2010/11/30 20:24:26 karthik Exp $

/**
 * Menu callback: Display a table of available schemes.
 */
function _node_style_schemes() {
  $result = db_query("SELECT s.name, s.sid, COUNT(m.sid) AS count FROM {node_style_schemes} s LEFT JOIN {node_style_maps} m USING (sid) GROUP BY s.sid, s.name ORDER BY s.name");
  $rows = array();
  while ($row = db_fetch_array($result)) {
    $rows[] = array(check_plain($row['name']), $row['count'], l(t('Edit'), 'admin/build/node_style/edit/'. $row['sid']), l(t('Delete'), 'admin/build/node_style/delete/'. $row['sid']));
  }
  if (empty($rows)) {
    $rows[] = array(array('data' => t('No schemes found.'), 'colspan' => 4));
  }
  $header = array(t('Scheme'), t('Use count'), array('data' => t('Operations'), 'colspan' => 2));

  return theme('table', $header, $rows);
}

/**
 * Menu callback: Add a new scheme.
 */
function _node_style_schemes_add(&$form_state, $sid = NULL) {
  $hide_array = _node_style_get_arrays();
  $scheme = array();

  if (isset($sid)) {
    $scheme = _node_style_get_scheme($sid);
    if (isset($scheme)) {
      $form['sid'] = array('#type' => 'value', '#value' => $sid);
    }
  }

  $form['name'] = array(
    '#type' => 'textfield',
    '#title' => t('Scheme name'),
    '#description' => t('A name to identify this scheme in a node form.'),
    '#default_value' => isset($scheme['name']) ? $scheme['name'] : '',
    '#required' => TRUE
  );
  $form['display'] = array(
    '#type' => 'fieldset',
    '#title' => t('Display settings'),
    '#tree' => TRUE,
    '#collapsible' => TRUE,
    '#collapsed' => FALSE
  );
  foreach ($hide_array as $hook => $values) {
    $form['display'][$hook] = array(
      '#type' => 'checkboxes',
      '#title' => t('Hide the following %hook elements', array('%hook' => $hook)),
      '#options' => $hide_array[$hook],
      '#default_value' => isset($scheme['variables']['display'][$hook]) ? $scheme['variables']['display'][$hook] : array(),
    );
  }

  $themes = list_themes();
  $options = array();
  foreach ($themes as $id => $theme) {
    // There is a possibility of discrepancies here if a selected theme is
    // disabled in the theme admin pages after being enabled here.
    if ($theme->status == 1) {
      $options[$id] = $theme->name;
    }
  }
  asort($options);
  $options = array('default' => t('default')) + $options;

  $form['misc'] = array(
    '#type' => 'fieldset',
    '#title' => t('Miscellaneous settings'),
    '#tree' => TRUE,
    '#collapsible' => TRUE,
    '#collapsed' => FALSE
  );
  $form['misc']['theme'] = array(
    '#type' => 'select',
    '#title' => t('Select a theme to display for this node'),
    '#description' => t('Select default to use the default theme.'),
    '#options' => $options,
    '#default_value' => isset($scheme['variables']) ? $scheme['variables']['misc']['theme'] : array()
  );
  $form['misc']['head'] = array(
    '#type' => 'textarea',
    '#title' => t('Insert mark-up into &lt;head&gt;&lt;head/&gt;'),
    '#description' => t('e.g. Add a stylesheet: &lt;style type="text/css" media="all"&gt;@import "/misc/drupal.css";&lt;/style&gt; or a Javascript file etc.'),
    '#default_value' => isset($scheme['variables']) ? $scheme['variables']['misc']['head'] : '',
    '#rows' => 6,
    '#resizable' => TRUE
  );

  $form['submit'] = array('#type' => 'submit', '#value' => t('Save scheme'));
  $form['#submit'][] = 'node_style_scheme_submit';
  $form['#redirect'] = 'admin/build/node_style';

  return $form;
}

/**
 * Menu callback: Edit a scheme.
 */
function _node_style_schemes_edit(&$form_state, $sid = NULL) {
  if (isset($sid)) {
    return _node_style_schemes_add($form_state, $sid);
  }
  else {
    drupal_set_message(t('Scheme not found.'), 'error');
    drupal_goto('admin/build/node_style');
  }
}

/**
 * Process a scheme add / edit form submission.
 */
function node_style_scheme_submit($form, &$form_state) {
  $scheme = array('display' => array(), 'misc' => array());

  $scheme['display']['node'] = array_filter($form_state['values']['display']['node']);
  $scheme['display']['node'] = array_keys($scheme['display']['node']);
  $scheme['display']['page'] = array_filter($form_state['values']['display']['page']);
  $scheme['display']['page'] = array_keys($scheme['display']['page']);
  $scheme['misc']['theme'] = $form_state['values']['misc']['theme'];
  $scheme['misc']['head'] = $form_state['values']['misc']['head'];

  if (isset($form_state['values']['sid'])) {
    _node_style_update_scheme($form_state['values']['sid'], $form_state['values']['name'], $scheme);
    drupal_set_message(t('Style scheme %name updated successfully.', array('%name' => $form_state['values']['name'])));
  }
  else {
    _node_style_add_scheme($form_state['values']['name'], $scheme);
    drupal_set_message(t('Style scheme %name added successfully.', array('%name' => $form_state['values']['name'])));
  }

  cache_clear_all();
}

/**
 * Menu callback: Delete a scheme.
 */
function _node_style_schemes_delete(&$form_state, $sid = NULL) {
  if (is_numeric($sid)) {
    $scheme = _node_style_get_scheme($sid);
    $form['sid'] = array('#type' => 'value', '#value' => $sid);
    $form['scheme_name'] = array('#type' => 'value', '#value' => $scheme['name']);
    $form['#redirect'] = 'admin/build/node_style';

    return confirm_form($form,
      t('Are you sure you want to delete the scheme %title?', array('%title' => $scheme['name'])),
      'admin/build/node_style/',
      t('This action cannot be undone.'),
      t('Delete'),
      t('Cancel')
    );
  }
  else {
    drupal_set_message(t('Scheme not found'), 'error');
  }
}

/**
 * Process a scheme deletion form submission.
 */
function _node_style_schemes_delete_submit($form, &$form_state) {
  db_query("DELETE FROM {node_style_maps} WHERE sid = %d", $form_state['values']['sid']);
  db_query("DELETE FROM {node_style_schemes} WHERE sid = %d", $form_state['values']['sid']);

  drupal_set_message(t('The scheme %title has been deleted.', array('%title' => $form_state['values']['scheme_name'])));
  watchdog('content', 'The scheme %title has been deleted.', array('%title' => $form_state['values']['scheme_name']));

  cache_clear_all();
}
